MODULE limtab_2
   !!======================================================================
   !!                       ***  MODULE limtab_2   ***
   !!   LIM 2 ice model : transform 1D (2D) array to a 2D (1D) array
   !!======================================================================
#if defined key_lim2
   !!----------------------------------------------------------------------
   !!   'key_lim2' :                                  LIM 2.0 sea-ice model
   !!----------------------------------------------------------------------
   !!   tab_2d_1d_2  : 2-D to 1-D
   !!   tab_1d_2d_2  : 1-D to 2-D
   !!----------------------------------------------------------------------
   USE par_kind

   IMPLICIT NONE
   PRIVATE

   PUBLIC   tab_2d_1d_2   ! called by lim_thd_2
   PUBLIC   tab_1d_2d_2   ! called by lim_thd_2

   !!----------------------------------------------------------------------
   !! NEMO/LIM 3.3,  UCL-LOCEAN-IPSL (2010) 
   !! $Id$
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
CONTAINS

   SUBROUTINE tab_2d_1d_2( kdim1d, ptab1d, ptab2d, kdim2d_i, kdim2d_j, ptab_ind )
      !!-------------------------------------------------------------------
      INTEGER , INTENT(in   )                                ::   kdim1d
      INTEGER , INTENT(in   )                                ::   kdim2d_i, kdim2d_j
      REAL(wp), INTENT(in   ), DIMENSION(kdim2d_i, kdim2d_j) ::   ptab2d
      INTEGER , INTENT(in   ), DIMENSION(kdim1d)             ::   ptab_ind
      REAL(wp), INTENT(  out), DIMENSION(kdim1d)             ::   ptab1d
      !!
      INTEGER ::   jn , jid, jjd   ! dummy loop indices
      !!-------------------------------------------------------------------
      ! 
      DO jn = 1, kdim1d
         jid = MOD( ptab_ind(jn) - 1, kdim2d_i ) + 1
         jjd = ( ptab_ind(jn) - 1 ) / kdim2d_i + 1
         ptab1d(jn) = ptab2d(jid,jjd)
      END DO 
      !
   END SUBROUTINE tab_2d_1d_2


   SUBROUTINE tab_1d_2d_2( kdim1d, ptab2d, ptab_ind, ptab1d, kdim2d_i, kdim2d_j )
      !!-------------------------------------------------------------------
      INTEGER , INTENT(in   )                                ::   kdim1d
      INTEGER , INTENT(in   )                                ::   kdim2d_i, kdim2d_j
      INTEGER , INTENT(in   ), DIMENSION(kdim1d)             ::   ptab_ind
      REAL(wp), INTENT(in   ), DIMENSION(kdim1d)             ::   ptab1d
      REAL(wp), INTENT(  out), DIMENSION(kdim2d_i, kdim2d_j) ::   ptab2d
      !!
      INTEGER ::   jn, jid, jjd   ! dummy loop indices
      !!-------------------------------------------------------------------
      !
      DO jn = 1, kdim1d
         jid = MOD( ptab_ind(jn) - 1, kdim2d_i) + 1
         jjd =    ( ptab_ind(jn) - 1 ) / kdim2d_i  + 1
         ptab2d(jid,jjd) = ptab1d(jn)
      END DO
      !
   END SUBROUTINE tab_1d_2d_2

#else
   !!----------------------------------------------------------------------
   !!   Default option          Dummy module       NO LIM 2.0 sea-ice model
   !!----------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE limtab_2
